webview2

package module
v0.0.0-...-6a9ee76 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 19, 2025 License: MIT Imports: 2 Imported by: 0

README

Go Report Card Go Reference

go-webview2

This package provides an interface for using the Microsoft Edge WebView2 component with Go. It is based on webview/webview and provides a compatible API.

Demo

If you are using Windows 10+, the WebView2 runtime should already be installed. If you don't have it installed, you can download and install a copy from Microsoft's website:

WebView2 runtime

After that, you should be able to run go-webview2 directly:

go run ./cmd/demo

This will use go-winloader to load an embedded copy of WebView2Loader.dll. If you want, you can also provide a newer version of WebView2Loader.dll in the DLL search path and it should be picked up instead. It can be acquired from the WebView2 SDK (which is permissively licensed.)

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Hint

type Hint int

Hint is used to configure window sizing and resizing behavior.

const (
	// HintNone specifies that width and height are default size
	HintNone Hint = iota

	// HintFixed specifies that window size can not be changed by a user
	HintFixed

	// HintMin specifies that width and height are minimum bounds
	HintMin

	// HintMax specifies that width and height are maximum bounds
	HintMax
)

type HostResourceAccessKind

type HostResourceAccessKind = edge.COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND

HostResourceAccessKind specifies the kind of cross-origin resource access allowed for a virtual host name mapping.

const (
	// HostResourceAccessKindDeny denies all cross-origin resource access.
	HostResourceAccessKindDeny HostResourceAccessKind = edge.COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND_DENY
	// HostResourceAccessKindAllow allows all cross-origin resource access.
	HostResourceAccessKindAllow HostResourceAccessKind = edge.COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND_ALLOW
	// HostResourceAccessKindDenyCors denies CORS but allows other cross-origin resource access.
	HostResourceAccessKindDenyCors HostResourceAccessKind = edge.COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND_DENY_CORS
)

type WebView

type WebView interface {

	// Run runs the main loop until it's terminated. After this function exits -
	// you must destroy the webview.
	Run()

	// Terminate stops the main loop. It is safe to call this function from
	// a background thread.
	Terminate()

	// Dispatch posts a function to be executed on the main thread. You normally
	// do not need to call this function, unless you want to tweak the native
	// window.
	Dispatch(f func())

	// Destroy destroys a webview and closes the native window.
	Destroy()

	// Window returns a native window handle pointer. When using GTK backend the
	// pointer is GtkWindow pointer, when using Cocoa backend the pointer is
	// NSWindow pointer, when using Win32 backend the pointer is HWND pointer.
	Window() unsafe.Pointer

	// SetTitle updates the title of the native window. Must be called from the UI
	// thread.
	SetTitle(title string)

	// SetSize updates native window size. See Hint constants.
	SetSize(w int, h int, hint Hint)

	// Navigate navigates webview to the given URL. URL may be a data URI, i.e.
	// "data:text/text,<html>...</html>". It is often ok not to url-encode it
	// properly, webview will re-encode it for you.
	Navigate(url string)

	// SetHtml sets the webview HTML directly.
	// The origin of the page is `about:blank`.
	SetHtml(html string)

	// Init injects JavaScript code at the initialization of the new page. Every
	// time the webview will open a the new page - this initialization code will
	// be executed. It is guaranteed that code is executed before window.onload.
	Init(js string)

	// Eval evaluates arbitrary JavaScript code. Evaluation happens asynchronously,
	// also the result of the expression is ignored. Use RPC bindings if you want
	// to receive notifications about the results of the evaluation.
	Eval(js string)

	// Bind binds a callback function so that it will appear under the given name
	// as a global JavaScript function. Internally it uses webview_init().
	// Callback receives a request string and a user-provided argument pointer.
	// Request string is a JSON array of all the arguments passed to the
	// JavaScript function.
	//
	// f must be a function
	// f must return either value and error or just error
	Bind(name string, f interface{}) error

	// SetVirtualHostNameToFolderMapping sets a mapping between a virtual host name
	// and a folder path to make available to web content via that host name.
	// For example, mapping "assets.example" to "C:\app\assets" allows the web page
	// to load resources using "https://assets.example/..."
	// The accessKind parameter controls CORS behavior for the virtual host.
	SetVirtualHostNameToFolderMapping(hostName, folderPath string, accessKind HostResourceAccessKind) error

	// ClearVirtualHostNameToFolderMapping clears a virtual host name mapping
	// previously set with SetVirtualHostNameToFolderMapping.
	ClearVirtualHostNameToFolderMapping(hostName string) error
}

WebView is the interface for the webview.

Directories

Path Synopsis
cmd
demo command
password-demo command
internal
w32
pkg

Jump to