Documentation
¶
Index ¶
- Constants
- func IsEqualGUID(guid1 *GUID, guid2 *GUID) bool
- type COREWEBVIEW2_CAPTURE_PREVIEW_IMAGE_FORMAT
- type COREWEBVIEW2_COLOR
- type COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON
- type COREWEBVIEW2_DOWNLOAD_STATE
- type COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND
- type COREWEBVIEW2_KEY_EVENT_KIND
- type COREWEBVIEW2_MOVE_FOCUS_REASON
- type COREWEBVIEW2_PHYSICAL_KEY_STATUS
- type COREWEBVIEW2_WEB_ERROR_STATUS
- type COREWEBVIEW2_WEB_RESOURCE_CONTEXT
- type ComProc
- type GUID
- type ICoreWebView2AcceleratorKeyPressedEventArgs
- func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) AddRef() uintptr
- func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetHandled() (bool, error)
- func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetKeyEventKind() (COREWEBVIEW2_KEY_EVENT_KIND, error)
- func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetKeyEventLParam() (int32, error)
- func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetPhysicalKeyStatus() (COREWEBVIEW2_PHYSICAL_KEY_STATUS, error)
- func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetVirtualKey() (uint, error)
- func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) PutHandled(handled bool) error
- type ICoreWebView2AcceleratorKeyPressedEventHandler
- type ICoreWebView2BytesReceivedChangedEventHandler
- type ICoreWebView2Controller
- func (i *ICoreWebView2Controller) AddAcceleratorKeyPressed(eventHandler *ICoreWebView2AcceleratorKeyPressedEventHandler, ...) error
- func (i *ICoreWebView2Controller) AddGotFocusRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2Controller) AddLostFocusRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2Controller) AddMoveFocusRequestedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2Controller) AddRef() uintptr
- func (i *ICoreWebView2Controller) AddZoomFactorChangedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2Controller) Close() error
- func (i *ICoreWebView2Controller) GetBounds() (*w32.Rect, error)
- func (i *ICoreWebView2Controller) GetCoreWebView2() (*ICoreWebView2, error)
- func (i *ICoreWebView2Controller) GetICoreWebView2Controller2() *ICoreWebView2Controller2
- func (i *ICoreWebView2Controller) GetIsVisible() (bool, error)
- func (i *ICoreWebView2Controller) GetParentWindow() (uintptr, error)
- func (i *ICoreWebView2Controller) GetZoomFactor() (float64, error)
- func (i *ICoreWebView2Controller) MoveFocus(reason uintptr) error
- func (i *ICoreWebView2Controller) NotifyParentWindowPositionChanged() error
- func (i *ICoreWebView2Controller) PutBounds(bounds w32.Rect) error
- func (i *ICoreWebView2Controller) PutIsVisible(isVisible bool) error
- func (i *ICoreWebView2Controller) PutParentWindow(hwnd uintptr) error
- func (i *ICoreWebView2Controller) PutZoomFactor(zoomFactor float64) error
- func (i *ICoreWebView2Controller) RemoveAcceleratorKeyPressed(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller) RemoveGotFocus(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller) RemoveLostFocus(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller) RemoveMoveFocusRequested(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller) RemoveZoomFactorChanged(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller) SetBoundsAndZoomFactor(bounds w32.Rect, zoomFactor float64) error
- type ICoreWebView2Controller2
- func (i *ICoreWebView2Controller2) AddAcceleratorKeyPressed(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) AddGotFocusRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) AddLostFocusRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) AddMoveFocusRequestedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) AddRef() uintptr
- func (i *ICoreWebView2Controller2) AddZoomFactorChangedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) Close() error
- func (i *ICoreWebView2Controller2) GetBounds() (*w32.Rect, error)
- func (i *ICoreWebView2Controller2) GetCoreWebView2() (*ICoreWebView2, error)
- func (i *ICoreWebView2Controller2) GetDefaultBackgroundColor() (*COREWEBVIEW2_COLOR, error)
- func (i *ICoreWebView2Controller2) GetIsVisible() (bool, error)
- func (i *ICoreWebView2Controller2) GetParentWindow() (uintptr, error)
- func (i *ICoreWebView2Controller2) GetZoomFactor() (float64, error)
- func (i *ICoreWebView2Controller2) MoveFocus(reason uintptr) error
- func (i *ICoreWebView2Controller2) NotifyParentWindowPositionChanged() error
- func (i *ICoreWebView2Controller2) PutBounds(bounds w32.Rect) error
- func (i *ICoreWebView2Controller2) PutDefaultBackgroundColor(backgroundColor COREWEBVIEW2_COLOR) error
- func (i *ICoreWebView2Controller2) PutIsVisible(isVisible bool) error
- func (i *ICoreWebView2Controller2) PutParentWindow(hwnd uintptr) error
- func (i *ICoreWebView2Controller2) PutZoomFactor(zoomFactor float64) error
- func (i *ICoreWebView2Controller2) RemoveAcceleratorKeyPressed(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) RemoveGotFocus(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) RemoveLostFocus(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) RemoveMoveFocusRequested(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) RemoveZoomFactorChanged(token _EventRegistrationToken) error
- func (i *ICoreWebView2Controller2) SetBoundsAndZoomFactor(bounds w32.Rect, zoomFactor float64) error
- type ICoreWebView2DownloadOperation
- func (i *ICoreWebView2DownloadOperation) AddBytesReceivedChangedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2DownloadOperation) AddEstimatedEndTimeChangedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2DownloadOperation) AddRef() uintptr
- func (i *ICoreWebView2DownloadOperation) AddStateChangedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2DownloadOperation) Cancel() error
- func (i *ICoreWebView2DownloadOperation) GetBytesReceived() (int64, error)
- func (i *ICoreWebView2DownloadOperation) GetCanResume() (bool, error)
- func (i *ICoreWebView2DownloadOperation) GetContentDisposition() (string, error)
- func (i *ICoreWebView2DownloadOperation) GetEstimatedEndTime() (string, error)
- func (i *ICoreWebView2DownloadOperation) GetInterruptReason() (COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON, error)
- func (i *ICoreWebView2DownloadOperation) GetMimeType() (string, error)
- func (i *ICoreWebView2DownloadOperation) GetResultFilePath() (string, error)
- func (i *ICoreWebView2DownloadOperation) GetState() (COREWEBVIEW2_DOWNLOAD_STATE, error)
- func (i *ICoreWebView2DownloadOperation) GetTotalBytesToReceive() (int64, error)
- func (i *ICoreWebView2DownloadOperation) GetUri() (string, error)
- func (i *ICoreWebView2DownloadOperation) Pause() error
- func (i *ICoreWebView2DownloadOperation) RemoveBytesReceivedChanged(token _EventRegistrationToken) error
- func (i *ICoreWebView2DownloadOperation) RemoveEstimatedEndTimeChanged(token _EventRegistrationToken) error
- func (i *ICoreWebView2DownloadOperation) RemoveStateChanged(token _EventRegistrationToken) error
- func (i *ICoreWebView2DownloadOperation) Resume() error
- type ICoreWebView2DownloadStartingEventArgs
- func (i *ICoreWebView2DownloadStartingEventArgs) AddRef() uintptr
- func (i *ICoreWebView2DownloadStartingEventArgs) GetCancel() (bool, error)
- func (i *ICoreWebView2DownloadStartingEventArgs) GetDeferral() (uintptr, error)
- func (i *ICoreWebView2DownloadStartingEventArgs) GetDownloadOperation() (*ICoreWebView2DownloadOperation, error)
- func (i *ICoreWebView2DownloadStartingEventArgs) GetHandled() (bool, error)
- func (i *ICoreWebView2DownloadStartingEventArgs) GetResultFilePath() (string, error)
- func (i *ICoreWebView2DownloadStartingEventArgs) PutCancel(cancel bool) error
- func (i *ICoreWebView2DownloadStartingEventArgs) PutHandled(handled bool) error
- func (i *ICoreWebView2DownloadStartingEventArgs) PutResultFilePath(resultFilePath string) error
- type ICoreWebView2EstimatedEndTimeChangedEventHandler
- type ICoreWebView2NavigationCompletedEventArgs
- func (i *ICoreWebView2NavigationCompletedEventArgs) AddRef() uintptr
- func (i *ICoreWebView2NavigationCompletedEventArgs) GetIsSuccess() (bool, error)
- func (i *ICoreWebView2NavigationCompletedEventArgs) GetNavigationID() (uint64, error)
- func (i *ICoreWebView2NavigationCompletedEventArgs) GetWebErrorStatus() (COREWEBVIEW2_WEB_ERROR_STATUS, error)
- type ICoreWebView2NavigationCompletedEventHandler
- type ICoreWebView2Settings
- func (i *ICoreWebView2Settings) AddRef() uintptr
- func (i *ICoreWebView2Settings) GetAreDefaultContextMenusEnabled() (bool, error)
- func (i *ICoreWebView2Settings) GetAreDefaultScriptDialogsEnabled() (bool, error)
- func (i *ICoreWebView2Settings) GetAreDevToolsEnabled() (bool, error)
- func (i *ICoreWebView2Settings) GetAreHostObjectsAllowed() (bool, error)
- func (i *ICoreWebView2Settings) GetIsBuiltInErrorPageEnabled() (bool, error)
- func (i *ICoreWebView2Settings) GetIsScriptEnabled() (bool, error)
- func (i *ICoreWebView2Settings) GetIsStatusBarEnabled() (bool, error)
- func (i *ICoreWebView2Settings) GetIsWebMessageEnabled() (bool, error)
- func (i *ICoreWebView2Settings) GetIsZoomControlEnabled() (bool, error)
- func (i *ICoreWebView2Settings) PutAreDefaultContextMenusEnabled(enabled bool) error
- func (i *ICoreWebView2Settings) PutAreDefaultScriptDialogsEnabled(areDefaultScriptDialogsEnabled bool) error
- func (i *ICoreWebView2Settings) PutAreDevToolsEnabled(areDevToolsEnabled bool) error
- func (i *ICoreWebView2Settings) PutAreHostObjectsAllowed(allowed bool) error
- func (i *ICoreWebView2Settings) PutIsBuiltInErrorPageEnabled(enabled bool) error
- func (i *ICoreWebView2Settings) PutIsScriptEnabled(isScriptEnabled bool) error
- func (i *ICoreWebView2Settings) PutIsStatusBarEnabled(isStatusBarEnabled bool) error
- func (i *ICoreWebView2Settings) PutIsWebMessageEnabled(isWebMessageEnabled bool) error
- func (i *ICoreWebView2Settings) PutIsZoomControlEnabled(enabled bool) error
- type ICoreWebView2StateChangedEventHandler
- type ICoreWebView2WebResourceRequest
- func (i *ICoreWebView2WebResourceRequest) AddRef() uintptr
- func (i *ICoreWebView2WebResourceRequest) GetContent() (uintptr, error)
- func (i *ICoreWebView2WebResourceRequest) GetHeaders() (uintptr, error)
- func (i *ICoreWebView2WebResourceRequest) GetMethod() (string, error)
- func (i *ICoreWebView2WebResourceRequest) GetUri() (string, error)
- func (i *ICoreWebView2WebResourceRequest) PutContent(stream uintptr) error
- func (i *ICoreWebView2WebResourceRequest) PutMethod(method string) error
- func (i *ICoreWebView2WebResourceRequest) PutUri(uri string) error
- type ICoreWebView2WebResourceRequestedEventArgs
- func (i *ICoreWebView2WebResourceRequestedEventArgs) AddRef() uintptr
- func (i *ICoreWebView2WebResourceRequestedEventArgs) GetDeferral() (uintptr, error)
- func (i *ICoreWebView2WebResourceRequestedEventArgs) GetRequest() (*ICoreWebView2WebResourceRequest, error)
- func (i *ICoreWebView2WebResourceRequestedEventArgs) GetResourceContext() (COREWEBVIEW2_WEB_RESOURCE_CONTEXT, error)
- func (i *ICoreWebView2WebResourceRequestedEventArgs) GetResponse() (*ICoreWebView2WebResourceResponse, error)
- func (i *ICoreWebView2WebResourceRequestedEventArgs) PutResponse(response *ICoreWebView2WebResourceResponse) error
- type ICoreWebView2WebResourceResponse
- func (i *ICoreWebView2WebResourceResponse) AddRef() uintptr
- func (i *ICoreWebView2WebResourceResponse) GetContent() (uintptr, error)
- func (i *ICoreWebView2WebResourceResponse) GetHeaders() (uintptr, error)
- func (i *ICoreWebView2WebResourceResponse) GetReasonPhrase() (string, error)
- func (i *ICoreWebView2WebResourceResponse) GetStatusCode() (int32, error)
- func (i *ICoreWebView2WebResourceResponse) PutContent(stream uintptr) error
- func (i *ICoreWebView2WebResourceResponse) PutReasonPhrase(phrase string) error
- func (i *ICoreWebView2WebResourceResponse) PutStatusCode(code int32) error
- type ICoreWebView2_2
- func (i *ICoreWebView2_2) AddDomContentLoadedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2_2) AddRef() uintptr
- func (i *ICoreWebView2_2) AddWebResourceResponseReceivedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2_2) GetCookieManager() (uintptr, error)
- func (i *ICoreWebView2_2) GetEnvironment() (*ICoreWebView2Environment, error)
- func (i *ICoreWebView2_2) NavigateWithWebResourceRequest(request *ICoreWebView2WebResourceRequest) error
- func (i *ICoreWebView2_2) RemoveDomContentLoaded(token _EventRegistrationToken) error
- func (i *ICoreWebView2_2) RemoveWebResourceResponseReceived(token _EventRegistrationToken) error
- type ICoreWebView2_3
- func (i *ICoreWebView2_3) ClearVirtualHostNameToFolderMapping(hostName string) error
- func (i *ICoreWebView2_3) GetIsSuspended() (bool, error)
- func (i *ICoreWebView2_3) Resume() error
- func (i *ICoreWebView2_3) SetVirtualHostNameToFolderMapping(hostName, folderPath string, accessKind COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND) error
- func (i *ICoreWebView2_3) TrySuspendRaw(handler uintptr) error
- type ICoreWebView2_4
- func (i *ICoreWebView2_4) AddDownloadStartingRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2_4) AddFrameCreatedRaw(handler uintptr, token *_EventRegistrationToken) error
- func (i *ICoreWebView2_4) RemoveDownloadStarting(token _EventRegistrationToken) error
- func (i *ICoreWebView2_4) RemoveFrameCreated(token _EventRegistrationToken) error
- type ICoreWebViewSettings
- func (i *ICoreWebViewSettings) AddRef() uintptr
- func (i *ICoreWebViewSettings) GetAreBrowserAcceleratorKeysEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetAreDefaultContextMenusEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetAreDefaultScriptDialogsEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetAreDevToolsEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetAreHostObjectsAllowed() (bool, error)
- func (i *ICoreWebViewSettings) GetIsBuiltInErrorPageEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetIsGeneralAutofillEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetIsPasswordAutosaveEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetIsPinchZoomEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetIsScriptEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetIsStatusBarEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetIsSwipeNavigationEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetIsWebMessageEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetIsZoomControlEnabled() (bool, error)
- func (i *ICoreWebViewSettings) GetUserAgent() (string, error)
- func (i *ICoreWebViewSettings) PutAreBrowserAcceleratorKeysEnabled(enabled bool) error
- func (i *ICoreWebViewSettings) PutAreDefaultContextMenusEnabled(enabled bool) error
- func (i *ICoreWebViewSettings) PutAreDefaultScriptDialogsEnabled(areDefaultScriptDialogsEnabled bool) error
- func (i *ICoreWebViewSettings) PutAreDevToolsEnabled(areDevToolsEnabled bool) error
- func (i *ICoreWebViewSettings) PutAreHostObjectsAllowed(allowed bool) error
- func (i *ICoreWebViewSettings) PutIsBuiltInErrorPageEnabled(enabled bool) error
- func (i *ICoreWebViewSettings) PutIsGeneralAutofillEnabled(enabled bool) error
- func (i *ICoreWebViewSettings) PutIsPasswordAutosaveEnabled(enabled bool) error
- func (i *ICoreWebViewSettings) PutIsPinchZoomEnabled(enabled bool) error
- func (i *ICoreWebViewSettings) PutIsScriptEnabled(isScriptEnabled bool) error
- func (i *ICoreWebViewSettings) PutIsStatusBarEnabled(isStatusBarEnabled bool) error
- func (i *ICoreWebViewSettings) PutIsSwipeNavigationEnabled(enabled bool) error
- func (i *ICoreWebViewSettings) PutIsWebMessageEnabled(isWebMessageEnabled bool) error
- func (i *ICoreWebViewSettings) PutIsZoomControlEnabled(enabled bool) error
- func (i *ICoreWebViewSettings) PutUserAgent(userAgent string) error
Constants ¶
const ( COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND_DENY = iota COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND_ALLOW COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND_DENY_CORS )
const ( COREWEBVIEW2_KEY_EVENT_KIND_KEY_DOWN = 0 COREWEBVIEW2_KEY_EVENT_KIND_KEY_UP = 1 COREWEBVIEW2_KEY_EVENT_KIND_SYSTEM_KEY_DOWN = 2 COREWEBVIEW2_KEY_EVENT_KIND_SYSTEM_KEY_UP = 3 )
const ( COREWEBVIEW2_MOVE_FOCUS_REASON_PROGRAMMATIC = 0 COREWEBVIEW2_MOVE_FOCUS_REASON_NEXT = 1 COREWEBVIEW2_MOVE_FOCUS_REASON_PREVIOUS = 2 )
const ( COREWEBVIEW2_WEB_RESOURCE_CONTEXT_ALL = 0 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_DOCUMENT = 1 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_STYLESHEET = 2 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_IMAGE = 3 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_MEDIA = 4 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_FONT = 5 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_SCRIPT = 6 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_XML_HTTP_REQUEST = 7 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_FETCH = 8 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_TEXT_TRACK = 9 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_EVENT_SOURCE = 10 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_WEBSOCKET = 11 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_MANIFEST = 12 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_SIGNED_EXCHANGE = 13 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_PING = 14 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_CSP_VIOLATION_REPORT = 15 COREWEBVIEW2_WEB_RESOURCE_CONTEXT_OTHER = 16 )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type COREWEBVIEW2_CAPTURE_PREVIEW_IMAGE_FORMAT ¶
type COREWEBVIEW2_CAPTURE_PREVIEW_IMAGE_FORMAT uint32
type COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON ¶
type COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON uint32
const ( COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_NONE COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 0 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_FAILED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 1 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_ACCESS_DENIED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 2 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_NO_SPACE COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 3 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_NAME_TOO_LONG COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 4 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_TOO_LARGE COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 5 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_MALICIOUS COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 6 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_TRANSIENT_ERROR COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 7 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_BLOCKED_BY_POLICY COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 8 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_SECURITY_CHECK_FAILED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 9 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_TOO_SHORT COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 10 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_FILE_HASH_MISMATCH COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 11 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_NETWORK_FAILED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 12 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_NETWORK_TIMEOUT COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 13 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_NETWORK_DISCONNECTED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 14 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_NETWORK_SERVER_DOWN COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 15 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_NETWORK_INVALID_REQUEST COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 16 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_SERVER_FAILED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 17 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_SERVER_NO_RANGE COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 18 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_SERVER_BAD_CONTENT COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 19 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_SERVER_UNAUTHORIZED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 20 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_SERVER_CERTIFICATE_PROBLEM COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 21 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_SERVER_FORBIDDEN COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 22 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_SERVER_UNEXPECTED_RESPONSE COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 23 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_SERVER_CONTENT_LENGTH_MISMATCH COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 24 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_SERVER_CROSS_ORIGIN_REDIRECT COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 25 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_USER_CANCELED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 26 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_USER_SHUTDOWN COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 27 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_USER_PAUSED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 28 COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON_DOWNLOAD_PROCESS_CRASHED COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON = 29 )
type COREWEBVIEW2_DOWNLOAD_STATE ¶
type COREWEBVIEW2_DOWNLOAD_STATE uint32
const ( COREWEBVIEW2_DOWNLOAD_STATE_IN_PROGRESS COREWEBVIEW2_DOWNLOAD_STATE = 0 COREWEBVIEW2_DOWNLOAD_STATE_INTERRUPTED COREWEBVIEW2_DOWNLOAD_STATE = 1 COREWEBVIEW2_DOWNLOAD_STATE_COMPLETED COREWEBVIEW2_DOWNLOAD_STATE = 2 )
type COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND ¶
type COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND uint32
type COREWEBVIEW2_KEY_EVENT_KIND ¶
type COREWEBVIEW2_KEY_EVENT_KIND uint32
type COREWEBVIEW2_MOVE_FOCUS_REASON ¶
type COREWEBVIEW2_MOVE_FOCUS_REASON uint32
type COREWEBVIEW2_WEB_ERROR_STATUS ¶
type COREWEBVIEW2_WEB_ERROR_STATUS uint32
type COREWEBVIEW2_WEB_RESOURCE_CONTEXT ¶
type COREWEBVIEW2_WEB_RESOURCE_CONTEXT uint32
type ComProc ¶
type ComProc uintptr
ComProc stores a COM procedure.
func NewComProc ¶
func NewComProc(fn interface{}) ComProc
NewComProc creates a new COM proc from a Go function.
type GUID ¶
GUID is Windows API specific GUID type.
This exists to match Windows GUID type for direct passing for COM. Format is in xxxxxxxx-xxxx-xxxx-xxxxxxxxxxxxxxxx.
func NewGUID ¶
NewGUID converts the given string into a globally unique identifier that is compliant with the Windows API.
The supplied string may be in any of these formats:
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX
{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}
The conversion of the supplied string is not case-sensitive.
type ICoreWebView2AcceleratorKeyPressedEventArgs ¶
type ICoreWebView2AcceleratorKeyPressedEventArgs struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2AcceleratorKeyPressedEventArgs) AddRef ¶
func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) AddRef() uintptr
func (*ICoreWebView2AcceleratorKeyPressedEventArgs) GetHandled ¶
func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetHandled() (bool, error)
func (*ICoreWebView2AcceleratorKeyPressedEventArgs) GetKeyEventKind ¶
func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetKeyEventKind() (COREWEBVIEW2_KEY_EVENT_KIND, error)
func (*ICoreWebView2AcceleratorKeyPressedEventArgs) GetKeyEventLParam ¶
func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetKeyEventLParam() (int32, error)
func (*ICoreWebView2AcceleratorKeyPressedEventArgs) GetPhysicalKeyStatus ¶
func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetPhysicalKeyStatus() (COREWEBVIEW2_PHYSICAL_KEY_STATUS, error)
func (*ICoreWebView2AcceleratorKeyPressedEventArgs) GetVirtualKey ¶
func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) GetVirtualKey() (uint, error)
func (*ICoreWebView2AcceleratorKeyPressedEventArgs) PutHandled ¶
func (i *ICoreWebView2AcceleratorKeyPressedEventArgs) PutHandled(handled bool) error
type ICoreWebView2AcceleratorKeyPressedEventHandler ¶
type ICoreWebView2AcceleratorKeyPressedEventHandler struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2AcceleratorKeyPressedEventHandler) AddRef ¶
func (i *ICoreWebView2AcceleratorKeyPressedEventHandler) AddRef() uintptr
type ICoreWebView2BytesReceivedChangedEventHandler ¶
type ICoreWebView2BytesReceivedChangedEventHandler struct {
// contains filtered or unexported fields
}
func NewICoreWebView2BytesReceivedChangedEventHandler ¶
func NewICoreWebView2BytesReceivedChangedEventHandler(impl _ICoreWebView2BytesReceivedChangedEventHandlerImpl) *ICoreWebView2BytesReceivedChangedEventHandler
type ICoreWebView2Controller ¶
type ICoreWebView2Controller struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2Controller) AddAcceleratorKeyPressed ¶
func (i *ICoreWebView2Controller) AddAcceleratorKeyPressed(eventHandler *ICoreWebView2AcceleratorKeyPressedEventHandler, token *_EventRegistrationToken) error
func (*ICoreWebView2Controller) AddGotFocusRaw ¶
func (i *ICoreWebView2Controller) AddGotFocusRaw(handler uintptr, token *_EventRegistrationToken) error
AddGotFocusRaw registers a got-focus handler.
func (*ICoreWebView2Controller) AddLostFocusRaw ¶
func (i *ICoreWebView2Controller) AddLostFocusRaw(handler uintptr, token *_EventRegistrationToken) error
AddLostFocusRaw registers a lost-focus handler.
func (*ICoreWebView2Controller) AddMoveFocusRequestedRaw ¶
func (i *ICoreWebView2Controller) AddMoveFocusRequestedRaw(handler uintptr, token *_EventRegistrationToken) error
AddMoveFocusRequestedRaw registers a move-focus-requested handler.
func (*ICoreWebView2Controller) AddRef ¶
func (i *ICoreWebView2Controller) AddRef() uintptr
func (*ICoreWebView2Controller) AddZoomFactorChangedRaw ¶
func (i *ICoreWebView2Controller) AddZoomFactorChangedRaw(handler uintptr, token *_EventRegistrationToken) error
AddZoomFactorChangedRaw registers a zoom-factor-changed handler. handler must be a COM object pointer implementing the expected WebView2 handler interface.
func (*ICoreWebView2Controller) Close ¶
func (i *ICoreWebView2Controller) Close() error
func (*ICoreWebView2Controller) GetBounds ¶
func (i *ICoreWebView2Controller) GetBounds() (*w32.Rect, error)
func (*ICoreWebView2Controller) GetCoreWebView2 ¶
func (i *ICoreWebView2Controller) GetCoreWebView2() (*ICoreWebView2, error)
func (*ICoreWebView2Controller) GetICoreWebView2Controller2 ¶
func (i *ICoreWebView2Controller) GetICoreWebView2Controller2() *ICoreWebView2Controller2
func (*ICoreWebView2Controller) GetIsVisible ¶
func (i *ICoreWebView2Controller) GetIsVisible() (bool, error)
func (*ICoreWebView2Controller) GetParentWindow ¶
func (i *ICoreWebView2Controller) GetParentWindow() (uintptr, error)
func (*ICoreWebView2Controller) GetZoomFactor ¶
func (i *ICoreWebView2Controller) GetZoomFactor() (float64, error)
func (*ICoreWebView2Controller) MoveFocus ¶
func (i *ICoreWebView2Controller) MoveFocus(reason uintptr) error
func (*ICoreWebView2Controller) NotifyParentWindowPositionChanged ¶
func (i *ICoreWebView2Controller) NotifyParentWindowPositionChanged() error
func (*ICoreWebView2Controller) PutBounds ¶
func (i *ICoreWebView2Controller) PutBounds(bounds w32.Rect) error
func (*ICoreWebView2Controller) PutIsVisible ¶
func (i *ICoreWebView2Controller) PutIsVisible(isVisible bool) error
func (*ICoreWebView2Controller) PutParentWindow ¶
func (i *ICoreWebView2Controller) PutParentWindow(hwnd uintptr) error
func (*ICoreWebView2Controller) PutZoomFactor ¶
func (i *ICoreWebView2Controller) PutZoomFactor(zoomFactor float64) error
func (*ICoreWebView2Controller) RemoveAcceleratorKeyPressed ¶
func (i *ICoreWebView2Controller) RemoveAcceleratorKeyPressed(token _EventRegistrationToken) error
func (*ICoreWebView2Controller) RemoveGotFocus ¶
func (i *ICoreWebView2Controller) RemoveGotFocus(token _EventRegistrationToken) error
func (*ICoreWebView2Controller) RemoveLostFocus ¶
func (i *ICoreWebView2Controller) RemoveLostFocus(token _EventRegistrationToken) error
func (*ICoreWebView2Controller) RemoveMoveFocusRequested ¶
func (i *ICoreWebView2Controller) RemoveMoveFocusRequested(token _EventRegistrationToken) error
func (*ICoreWebView2Controller) RemoveZoomFactorChanged ¶
func (i *ICoreWebView2Controller) RemoveZoomFactorChanged(token _EventRegistrationToken) error
func (*ICoreWebView2Controller) SetBoundsAndZoomFactor ¶
func (i *ICoreWebView2Controller) SetBoundsAndZoomFactor(bounds w32.Rect, zoomFactor float64) error
type ICoreWebView2Controller2 ¶
type ICoreWebView2Controller2 struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2Controller2) AddAcceleratorKeyPressed ¶
func (i *ICoreWebView2Controller2) AddAcceleratorKeyPressed(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2Controller2) AddGotFocusRaw ¶
func (i *ICoreWebView2Controller2) AddGotFocusRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2Controller2) AddLostFocusRaw ¶
func (i *ICoreWebView2Controller2) AddLostFocusRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2Controller2) AddMoveFocusRequestedRaw ¶
func (i *ICoreWebView2Controller2) AddMoveFocusRequestedRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2Controller2) AddRef ¶
func (i *ICoreWebView2Controller2) AddRef() uintptr
func (*ICoreWebView2Controller2) AddZoomFactorChangedRaw ¶
func (i *ICoreWebView2Controller2) AddZoomFactorChangedRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2Controller2) Close ¶
func (i *ICoreWebView2Controller2) Close() error
func (*ICoreWebView2Controller2) GetBounds ¶
func (i *ICoreWebView2Controller2) GetBounds() (*w32.Rect, error)
func (*ICoreWebView2Controller2) GetCoreWebView2 ¶
func (i *ICoreWebView2Controller2) GetCoreWebView2() (*ICoreWebView2, error)
func (*ICoreWebView2Controller2) GetDefaultBackgroundColor ¶
func (i *ICoreWebView2Controller2) GetDefaultBackgroundColor() (*COREWEBVIEW2_COLOR, error)
func (*ICoreWebView2Controller2) GetIsVisible ¶
func (i *ICoreWebView2Controller2) GetIsVisible() (bool, error)
func (*ICoreWebView2Controller2) GetParentWindow ¶
func (i *ICoreWebView2Controller2) GetParentWindow() (uintptr, error)
func (*ICoreWebView2Controller2) GetZoomFactor ¶
func (i *ICoreWebView2Controller2) GetZoomFactor() (float64, error)
func (*ICoreWebView2Controller2) MoveFocus ¶
func (i *ICoreWebView2Controller2) MoveFocus(reason uintptr) error
func (*ICoreWebView2Controller2) NotifyParentWindowPositionChanged ¶
func (i *ICoreWebView2Controller2) NotifyParentWindowPositionChanged() error
func (*ICoreWebView2Controller2) PutBounds ¶
func (i *ICoreWebView2Controller2) PutBounds(bounds w32.Rect) error
func (*ICoreWebView2Controller2) PutDefaultBackgroundColor ¶
func (i *ICoreWebView2Controller2) PutDefaultBackgroundColor(backgroundColor COREWEBVIEW2_COLOR) error
func (*ICoreWebView2Controller2) PutIsVisible ¶
func (i *ICoreWebView2Controller2) PutIsVisible(isVisible bool) error
func (*ICoreWebView2Controller2) PutParentWindow ¶
func (i *ICoreWebView2Controller2) PutParentWindow(hwnd uintptr) error
func (*ICoreWebView2Controller2) PutZoomFactor ¶
func (i *ICoreWebView2Controller2) PutZoomFactor(zoomFactor float64) error
func (*ICoreWebView2Controller2) RemoveAcceleratorKeyPressed ¶
func (i *ICoreWebView2Controller2) RemoveAcceleratorKeyPressed(token _EventRegistrationToken) error
func (*ICoreWebView2Controller2) RemoveGotFocus ¶
func (i *ICoreWebView2Controller2) RemoveGotFocus(token _EventRegistrationToken) error
func (*ICoreWebView2Controller2) RemoveLostFocus ¶
func (i *ICoreWebView2Controller2) RemoveLostFocus(token _EventRegistrationToken) error
func (*ICoreWebView2Controller2) RemoveMoveFocusRequested ¶
func (i *ICoreWebView2Controller2) RemoveMoveFocusRequested(token _EventRegistrationToken) error
func (*ICoreWebView2Controller2) RemoveZoomFactorChanged ¶
func (i *ICoreWebView2Controller2) RemoveZoomFactorChanged(token _EventRegistrationToken) error
func (*ICoreWebView2Controller2) SetBoundsAndZoomFactor ¶
func (i *ICoreWebView2Controller2) SetBoundsAndZoomFactor(bounds w32.Rect, zoomFactor float64) error
type ICoreWebView2DownloadOperation ¶
type ICoreWebView2DownloadOperation struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2DownloadOperation) AddBytesReceivedChangedRaw ¶
func (i *ICoreWebView2DownloadOperation) AddBytesReceivedChangedRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2DownloadOperation) AddEstimatedEndTimeChangedRaw ¶
func (i *ICoreWebView2DownloadOperation) AddEstimatedEndTimeChangedRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2DownloadOperation) AddRef ¶
func (i *ICoreWebView2DownloadOperation) AddRef() uintptr
func (*ICoreWebView2DownloadOperation) AddStateChangedRaw ¶
func (i *ICoreWebView2DownloadOperation) AddStateChangedRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2DownloadOperation) Cancel ¶
func (i *ICoreWebView2DownloadOperation) Cancel() error
func (*ICoreWebView2DownloadOperation) GetBytesReceived ¶
func (i *ICoreWebView2DownloadOperation) GetBytesReceived() (int64, error)
func (*ICoreWebView2DownloadOperation) GetCanResume ¶
func (i *ICoreWebView2DownloadOperation) GetCanResume() (bool, error)
func (*ICoreWebView2DownloadOperation) GetContentDisposition ¶
func (i *ICoreWebView2DownloadOperation) GetContentDisposition() (string, error)
func (*ICoreWebView2DownloadOperation) GetEstimatedEndTime ¶
func (i *ICoreWebView2DownloadOperation) GetEstimatedEndTime() (string, error)
func (*ICoreWebView2DownloadOperation) GetInterruptReason ¶
func (i *ICoreWebView2DownloadOperation) GetInterruptReason() (COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON, error)
func (*ICoreWebView2DownloadOperation) GetMimeType ¶
func (i *ICoreWebView2DownloadOperation) GetMimeType() (string, error)
func (*ICoreWebView2DownloadOperation) GetResultFilePath ¶
func (i *ICoreWebView2DownloadOperation) GetResultFilePath() (string, error)
func (*ICoreWebView2DownloadOperation) GetState ¶
func (i *ICoreWebView2DownloadOperation) GetState() (COREWEBVIEW2_DOWNLOAD_STATE, error)
func (*ICoreWebView2DownloadOperation) GetTotalBytesToReceive ¶
func (i *ICoreWebView2DownloadOperation) GetTotalBytesToReceive() (int64, error)
func (*ICoreWebView2DownloadOperation) GetUri ¶
func (i *ICoreWebView2DownloadOperation) GetUri() (string, error)
func (*ICoreWebView2DownloadOperation) Pause ¶
func (i *ICoreWebView2DownloadOperation) Pause() error
func (*ICoreWebView2DownloadOperation) RemoveBytesReceivedChanged ¶
func (i *ICoreWebView2DownloadOperation) RemoveBytesReceivedChanged(token _EventRegistrationToken) error
func (*ICoreWebView2DownloadOperation) RemoveEstimatedEndTimeChanged ¶
func (i *ICoreWebView2DownloadOperation) RemoveEstimatedEndTimeChanged(token _EventRegistrationToken) error
func (*ICoreWebView2DownloadOperation) RemoveStateChanged ¶
func (i *ICoreWebView2DownloadOperation) RemoveStateChanged(token _EventRegistrationToken) error
func (*ICoreWebView2DownloadOperation) Resume ¶
func (i *ICoreWebView2DownloadOperation) Resume() error
type ICoreWebView2DownloadStartingEventArgs ¶
type ICoreWebView2DownloadStartingEventArgs struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2DownloadStartingEventArgs) AddRef ¶
func (i *ICoreWebView2DownloadStartingEventArgs) AddRef() uintptr
func (*ICoreWebView2DownloadStartingEventArgs) GetCancel ¶
func (i *ICoreWebView2DownloadStartingEventArgs) GetCancel() (bool, error)
func (*ICoreWebView2DownloadStartingEventArgs) GetDeferral ¶
func (i *ICoreWebView2DownloadStartingEventArgs) GetDeferral() (uintptr, error)
GetDeferral returns the underlying ICoreWebView2Deferral*. The concrete type is not wrapped here; use COM directly if needed.
func (*ICoreWebView2DownloadStartingEventArgs) GetDownloadOperation ¶
func (i *ICoreWebView2DownloadStartingEventArgs) GetDownloadOperation() (*ICoreWebView2DownloadOperation, error)
func (*ICoreWebView2DownloadStartingEventArgs) GetHandled ¶
func (i *ICoreWebView2DownloadStartingEventArgs) GetHandled() (bool, error)
func (*ICoreWebView2DownloadStartingEventArgs) GetResultFilePath ¶
func (i *ICoreWebView2DownloadStartingEventArgs) GetResultFilePath() (string, error)
func (*ICoreWebView2DownloadStartingEventArgs) PutCancel ¶
func (i *ICoreWebView2DownloadStartingEventArgs) PutCancel(cancel bool) error
func (*ICoreWebView2DownloadStartingEventArgs) PutHandled ¶
func (i *ICoreWebView2DownloadStartingEventArgs) PutHandled(handled bool) error
func (*ICoreWebView2DownloadStartingEventArgs) PutResultFilePath ¶
func (i *ICoreWebView2DownloadStartingEventArgs) PutResultFilePath(resultFilePath string) error
type ICoreWebView2EstimatedEndTimeChangedEventHandler ¶
type ICoreWebView2EstimatedEndTimeChangedEventHandler struct {
// contains filtered or unexported fields
}
func NewICoreWebView2EstimatedEndTimeChangedEventHandler ¶
func NewICoreWebView2EstimatedEndTimeChangedEventHandler(impl _ICoreWebView2EstimatedEndTimeChangedEventHandlerImpl) *ICoreWebView2EstimatedEndTimeChangedEventHandler
type ICoreWebView2NavigationCompletedEventArgs ¶
type ICoreWebView2NavigationCompletedEventArgs struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2NavigationCompletedEventArgs) AddRef ¶
func (i *ICoreWebView2NavigationCompletedEventArgs) AddRef() uintptr
func (*ICoreWebView2NavigationCompletedEventArgs) GetIsSuccess ¶
func (i *ICoreWebView2NavigationCompletedEventArgs) GetIsSuccess() (bool, error)
func (*ICoreWebView2NavigationCompletedEventArgs) GetNavigationID ¶
func (i *ICoreWebView2NavigationCompletedEventArgs) GetNavigationID() (uint64, error)
func (*ICoreWebView2NavigationCompletedEventArgs) GetWebErrorStatus ¶
func (i *ICoreWebView2NavigationCompletedEventArgs) GetWebErrorStatus() (COREWEBVIEW2_WEB_ERROR_STATUS, error)
type ICoreWebView2NavigationCompletedEventHandler ¶
type ICoreWebView2NavigationCompletedEventHandler struct {
// contains filtered or unexported fields
}
type ICoreWebView2Settings ¶
type ICoreWebView2Settings struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2Settings) AddRef ¶
func (i *ICoreWebView2Settings) AddRef() uintptr
func (*ICoreWebView2Settings) GetAreDefaultContextMenusEnabled ¶
func (i *ICoreWebView2Settings) GetAreDefaultContextMenusEnabled() (bool, error)
func (*ICoreWebView2Settings) GetAreDefaultScriptDialogsEnabled ¶
func (i *ICoreWebView2Settings) GetAreDefaultScriptDialogsEnabled() (bool, error)
func (*ICoreWebView2Settings) GetAreDevToolsEnabled ¶
func (i *ICoreWebView2Settings) GetAreDevToolsEnabled() (bool, error)
func (*ICoreWebView2Settings) GetAreHostObjectsAllowed ¶
func (i *ICoreWebView2Settings) GetAreHostObjectsAllowed() (bool, error)
func (*ICoreWebView2Settings) GetIsBuiltInErrorPageEnabled ¶
func (i *ICoreWebView2Settings) GetIsBuiltInErrorPageEnabled() (bool, error)
func (*ICoreWebView2Settings) GetIsScriptEnabled ¶
func (i *ICoreWebView2Settings) GetIsScriptEnabled() (bool, error)
func (*ICoreWebView2Settings) GetIsStatusBarEnabled ¶
func (i *ICoreWebView2Settings) GetIsStatusBarEnabled() (bool, error)
func (*ICoreWebView2Settings) GetIsWebMessageEnabled ¶
func (i *ICoreWebView2Settings) GetIsWebMessageEnabled() (bool, error)
func (*ICoreWebView2Settings) GetIsZoomControlEnabled ¶
func (i *ICoreWebView2Settings) GetIsZoomControlEnabled() (bool, error)
func (*ICoreWebView2Settings) PutAreDefaultContextMenusEnabled ¶
func (i *ICoreWebView2Settings) PutAreDefaultContextMenusEnabled(enabled bool) error
func (*ICoreWebView2Settings) PutAreDefaultScriptDialogsEnabled ¶
func (i *ICoreWebView2Settings) PutAreDefaultScriptDialogsEnabled(areDefaultScriptDialogsEnabled bool) error
func (*ICoreWebView2Settings) PutAreDevToolsEnabled ¶
func (i *ICoreWebView2Settings) PutAreDevToolsEnabled(areDevToolsEnabled bool) error
func (*ICoreWebView2Settings) PutAreHostObjectsAllowed ¶
func (i *ICoreWebView2Settings) PutAreHostObjectsAllowed(allowed bool) error
func (*ICoreWebView2Settings) PutIsBuiltInErrorPageEnabled ¶
func (i *ICoreWebView2Settings) PutIsBuiltInErrorPageEnabled(enabled bool) error
func (*ICoreWebView2Settings) PutIsScriptEnabled ¶
func (i *ICoreWebView2Settings) PutIsScriptEnabled(isScriptEnabled bool) error
func (*ICoreWebView2Settings) PutIsStatusBarEnabled ¶
func (i *ICoreWebView2Settings) PutIsStatusBarEnabled(isStatusBarEnabled bool) error
func (*ICoreWebView2Settings) PutIsWebMessageEnabled ¶
func (i *ICoreWebView2Settings) PutIsWebMessageEnabled(isWebMessageEnabled bool) error
func (*ICoreWebView2Settings) PutIsZoomControlEnabled ¶
func (i *ICoreWebView2Settings) PutIsZoomControlEnabled(enabled bool) error
type ICoreWebView2StateChangedEventHandler ¶
type ICoreWebView2StateChangedEventHandler struct {
// contains filtered or unexported fields
}
func NewICoreWebView2StateChangedEventHandler ¶
func NewICoreWebView2StateChangedEventHandler(impl _ICoreWebView2StateChangedEventHandlerImpl) *ICoreWebView2StateChangedEventHandler
type ICoreWebView2WebResourceRequest ¶
type ICoreWebView2WebResourceRequest struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2WebResourceRequest) AddRef ¶
func (i *ICoreWebView2WebResourceRequest) AddRef() uintptr
func (*ICoreWebView2WebResourceRequest) GetContent ¶
func (i *ICoreWebView2WebResourceRequest) GetContent() (uintptr, error)
GetContent returns the underlying IStream* for the request body.
func (*ICoreWebView2WebResourceRequest) GetHeaders ¶
func (i *ICoreWebView2WebResourceRequest) GetHeaders() (uintptr, error)
GetHeaders returns the underlying ICoreWebView2HttpRequestHeaders*. The concrete type is not wrapped here; use COM directly if needed.
func (*ICoreWebView2WebResourceRequest) GetMethod ¶
func (i *ICoreWebView2WebResourceRequest) GetMethod() (string, error)
func (*ICoreWebView2WebResourceRequest) GetUri ¶
func (i *ICoreWebView2WebResourceRequest) GetUri() (string, error)
func (*ICoreWebView2WebResourceRequest) PutContent ¶
func (i *ICoreWebView2WebResourceRequest) PutContent(stream uintptr) error
PutContent sets the underlying IStream* for the request body.
func (*ICoreWebView2WebResourceRequest) PutMethod ¶
func (i *ICoreWebView2WebResourceRequest) PutMethod(method string) error
func (*ICoreWebView2WebResourceRequest) PutUri ¶
func (i *ICoreWebView2WebResourceRequest) PutUri(uri string) error
type ICoreWebView2WebResourceRequestedEventArgs ¶
type ICoreWebView2WebResourceRequestedEventArgs struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2WebResourceRequestedEventArgs) AddRef ¶
func (i *ICoreWebView2WebResourceRequestedEventArgs) AddRef() uintptr
func (*ICoreWebView2WebResourceRequestedEventArgs) GetDeferral ¶
func (i *ICoreWebView2WebResourceRequestedEventArgs) GetDeferral() (uintptr, error)
GetDeferral returns the underlying ICoreWebView2Deferral*. The concrete type is not wrapped here; use COM directly if needed.
func (*ICoreWebView2WebResourceRequestedEventArgs) GetRequest ¶
func (i *ICoreWebView2WebResourceRequestedEventArgs) GetRequest() (*ICoreWebView2WebResourceRequest, error)
func (*ICoreWebView2WebResourceRequestedEventArgs) GetResourceContext ¶
func (i *ICoreWebView2WebResourceRequestedEventArgs) GetResourceContext() (COREWEBVIEW2_WEB_RESOURCE_CONTEXT, error)
func (*ICoreWebView2WebResourceRequestedEventArgs) GetResponse ¶
func (i *ICoreWebView2WebResourceRequestedEventArgs) GetResponse() (*ICoreWebView2WebResourceResponse, error)
func (*ICoreWebView2WebResourceRequestedEventArgs) PutResponse ¶
func (i *ICoreWebView2WebResourceRequestedEventArgs) PutResponse(response *ICoreWebView2WebResourceResponse) error
type ICoreWebView2WebResourceResponse ¶
type ICoreWebView2WebResourceResponse struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2WebResourceResponse) AddRef ¶
func (i *ICoreWebView2WebResourceResponse) AddRef() uintptr
func (*ICoreWebView2WebResourceResponse) GetContent ¶
func (i *ICoreWebView2WebResourceResponse) GetContent() (uintptr, error)
GetContent returns the underlying IStream* for the response body.
func (*ICoreWebView2WebResourceResponse) GetHeaders ¶
func (i *ICoreWebView2WebResourceResponse) GetHeaders() (uintptr, error)
GetHeaders returns the underlying ICoreWebView2HttpResponseHeaders*. The concrete type is not wrapped here; use COM directly if needed.
func (*ICoreWebView2WebResourceResponse) GetReasonPhrase ¶
func (i *ICoreWebView2WebResourceResponse) GetReasonPhrase() (string, error)
func (*ICoreWebView2WebResourceResponse) GetStatusCode ¶
func (i *ICoreWebView2WebResourceResponse) GetStatusCode() (int32, error)
func (*ICoreWebView2WebResourceResponse) PutContent ¶
func (i *ICoreWebView2WebResourceResponse) PutContent(stream uintptr) error
PutContent sets the underlying IStream* for the response body.
func (*ICoreWebView2WebResourceResponse) PutReasonPhrase ¶
func (i *ICoreWebView2WebResourceResponse) PutReasonPhrase(phrase string) error
func (*ICoreWebView2WebResourceResponse) PutStatusCode ¶
func (i *ICoreWebView2WebResourceResponse) PutStatusCode(code int32) error
type ICoreWebView2_2 ¶
type ICoreWebView2_2 struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2_2) AddDomContentLoadedRaw ¶
func (i *ICoreWebView2_2) AddDomContentLoadedRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2_2) AddRef ¶
func (i *ICoreWebView2_2) AddRef() uintptr
func (*ICoreWebView2_2) AddWebResourceResponseReceivedRaw ¶
func (i *ICoreWebView2_2) AddWebResourceResponseReceivedRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2_2) GetCookieManager ¶
func (i *ICoreWebView2_2) GetCookieManager() (uintptr, error)
GetCookieManager returns the underlying ICoreWebView2CookieManager*. The concrete type is not wrapped here; use COM directly if needed.
func (*ICoreWebView2_2) GetEnvironment ¶
func (i *ICoreWebView2_2) GetEnvironment() (*ICoreWebView2Environment, error)
func (*ICoreWebView2_2) NavigateWithWebResourceRequest ¶
func (i *ICoreWebView2_2) NavigateWithWebResourceRequest(request *ICoreWebView2WebResourceRequest) error
func (*ICoreWebView2_2) RemoveDomContentLoaded ¶
func (i *ICoreWebView2_2) RemoveDomContentLoaded(token _EventRegistrationToken) error
func (*ICoreWebView2_2) RemoveWebResourceResponseReceived ¶
func (i *ICoreWebView2_2) RemoveWebResourceResponseReceived(token _EventRegistrationToken) error
type ICoreWebView2_3 ¶
type ICoreWebView2_3 struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2_3) ClearVirtualHostNameToFolderMapping ¶
func (i *ICoreWebView2_3) ClearVirtualHostNameToFolderMapping(hostName string) error
func (*ICoreWebView2_3) GetIsSuspended ¶
func (i *ICoreWebView2_3) GetIsSuspended() (bool, error)
func (*ICoreWebView2_3) Resume ¶
func (i *ICoreWebView2_3) Resume() error
func (*ICoreWebView2_3) SetVirtualHostNameToFolderMapping ¶
func (i *ICoreWebView2_3) SetVirtualHostNameToFolderMapping(hostName, folderPath string, accessKind COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND) error
func (*ICoreWebView2_3) TrySuspendRaw ¶
func (i *ICoreWebView2_3) TrySuspendRaw(handler uintptr) error
TrySuspendRaw begins suspension; handler must be a COM object pointer implementing ICoreWebView2TrySuspendCompletedHandler.
type ICoreWebView2_4 ¶
type ICoreWebView2_4 struct {
// contains filtered or unexported fields
}
func (*ICoreWebView2_4) AddDownloadStartingRaw ¶
func (i *ICoreWebView2_4) AddDownloadStartingRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2_4) AddFrameCreatedRaw ¶
func (i *ICoreWebView2_4) AddFrameCreatedRaw(handler uintptr, token *_EventRegistrationToken) error
func (*ICoreWebView2_4) RemoveDownloadStarting ¶
func (i *ICoreWebView2_4) RemoveDownloadStarting(token _EventRegistrationToken) error
func (*ICoreWebView2_4) RemoveFrameCreated ¶
func (i *ICoreWebView2_4) RemoveFrameCreated(token _EventRegistrationToken) error
type ICoreWebViewSettings ¶
type ICoreWebViewSettings struct {
// contains filtered or unexported fields
}
func (*ICoreWebViewSettings) AddRef ¶
func (i *ICoreWebViewSettings) AddRef() uintptr
func (*ICoreWebViewSettings) GetAreBrowserAcceleratorKeysEnabled ¶
func (i *ICoreWebViewSettings) GetAreBrowserAcceleratorKeysEnabled() (bool, error)
func (*ICoreWebViewSettings) GetAreDefaultContextMenusEnabled ¶
func (i *ICoreWebViewSettings) GetAreDefaultContextMenusEnabled() (bool, error)
func (*ICoreWebViewSettings) GetAreDefaultScriptDialogsEnabled ¶
func (i *ICoreWebViewSettings) GetAreDefaultScriptDialogsEnabled() (bool, error)
func (*ICoreWebViewSettings) GetAreDevToolsEnabled ¶
func (i *ICoreWebViewSettings) GetAreDevToolsEnabled() (bool, error)
func (*ICoreWebViewSettings) GetAreHostObjectsAllowed ¶
func (i *ICoreWebViewSettings) GetAreHostObjectsAllowed() (bool, error)
func (*ICoreWebViewSettings) GetIsBuiltInErrorPageEnabled ¶
func (i *ICoreWebViewSettings) GetIsBuiltInErrorPageEnabled() (bool, error)
func (*ICoreWebViewSettings) GetIsGeneralAutofillEnabled ¶
func (i *ICoreWebViewSettings) GetIsGeneralAutofillEnabled() (bool, error)
func (*ICoreWebViewSettings) GetIsPasswordAutosaveEnabled ¶
func (i *ICoreWebViewSettings) GetIsPasswordAutosaveEnabled() (bool, error)
func (*ICoreWebViewSettings) GetIsPinchZoomEnabled ¶
func (i *ICoreWebViewSettings) GetIsPinchZoomEnabled() (bool, error)
func (*ICoreWebViewSettings) GetIsScriptEnabled ¶
func (i *ICoreWebViewSettings) GetIsScriptEnabled() (bool, error)
func (*ICoreWebViewSettings) GetIsStatusBarEnabled ¶
func (i *ICoreWebViewSettings) GetIsStatusBarEnabled() (bool, error)
func (*ICoreWebViewSettings) GetIsSwipeNavigationEnabled ¶
func (i *ICoreWebViewSettings) GetIsSwipeNavigationEnabled() (bool, error)
func (*ICoreWebViewSettings) GetIsWebMessageEnabled ¶
func (i *ICoreWebViewSettings) GetIsWebMessageEnabled() (bool, error)
func (*ICoreWebViewSettings) GetIsZoomControlEnabled ¶
func (i *ICoreWebViewSettings) GetIsZoomControlEnabled() (bool, error)
func (*ICoreWebViewSettings) GetUserAgent ¶
func (i *ICoreWebViewSettings) GetUserAgent() (string, error)
func (*ICoreWebViewSettings) PutAreBrowserAcceleratorKeysEnabled ¶
func (i *ICoreWebViewSettings) PutAreBrowserAcceleratorKeysEnabled(enabled bool) error
func (*ICoreWebViewSettings) PutAreDefaultContextMenusEnabled ¶
func (i *ICoreWebViewSettings) PutAreDefaultContextMenusEnabled(enabled bool) error
func (*ICoreWebViewSettings) PutAreDefaultScriptDialogsEnabled ¶
func (i *ICoreWebViewSettings) PutAreDefaultScriptDialogsEnabled(areDefaultScriptDialogsEnabled bool) error
func (*ICoreWebViewSettings) PutAreDevToolsEnabled ¶
func (i *ICoreWebViewSettings) PutAreDevToolsEnabled(areDevToolsEnabled bool) error
func (*ICoreWebViewSettings) PutAreHostObjectsAllowed ¶
func (i *ICoreWebViewSettings) PutAreHostObjectsAllowed(allowed bool) error
func (*ICoreWebViewSettings) PutIsBuiltInErrorPageEnabled ¶
func (i *ICoreWebViewSettings) PutIsBuiltInErrorPageEnabled(enabled bool) error
func (*ICoreWebViewSettings) PutIsGeneralAutofillEnabled ¶
func (i *ICoreWebViewSettings) PutIsGeneralAutofillEnabled(enabled bool) error
func (*ICoreWebViewSettings) PutIsPasswordAutosaveEnabled ¶
func (i *ICoreWebViewSettings) PutIsPasswordAutosaveEnabled(enabled bool) error
func (*ICoreWebViewSettings) PutIsPinchZoomEnabled ¶
func (i *ICoreWebViewSettings) PutIsPinchZoomEnabled(enabled bool) error
func (*ICoreWebViewSettings) PutIsScriptEnabled ¶
func (i *ICoreWebViewSettings) PutIsScriptEnabled(isScriptEnabled bool) error
func (*ICoreWebViewSettings) PutIsStatusBarEnabled ¶
func (i *ICoreWebViewSettings) PutIsStatusBarEnabled(isStatusBarEnabled bool) error
func (*ICoreWebViewSettings) PutIsSwipeNavigationEnabled ¶
func (i *ICoreWebViewSettings) PutIsSwipeNavigationEnabled(enabled bool) error
func (*ICoreWebViewSettings) PutIsWebMessageEnabled ¶
func (i *ICoreWebViewSettings) PutIsWebMessageEnabled(isWebMessageEnabled bool) error
func (*ICoreWebViewSettings) PutIsZoomControlEnabled ¶
func (i *ICoreWebViewSettings) PutIsZoomControlEnabled(enabled bool) error
func (*ICoreWebViewSettings) PutUserAgent ¶
func (i *ICoreWebViewSettings) PutUserAgent(userAgent string) error
Source Files
¶
- COREWEBVIEW2_CAPTURE_PREVIEW_IMAGE_FORMAT.go
- COREWEBVIEW2_COLOR.go
- COREWEBVIEW2_DOWNLOAD_INTERRUPT_REASON.go
- COREWEBVIEW2_DOWNLOAD_STATE.go
- COREWEBVIEW2_HOST_RESOURCE_ACCESS_KIND.go
- COREWEBVIEW2_KEY_EVENT_KIND.go
- COREWEBVIEW2_MOVE_FOCUS_REASON.go
- COREWEBVIEW2_PHYSICAL_KEY_STATUS.go
- COREWEBVIEW2_WEB_ERROR_STATUS.go
- COREWEBVIEW2_WEB_RESOURCE_CONTEXT.go
- ICoreWebView2AcceleratorKeyPressedEventArgs.go
- ICoreWebView2AcceleratorKeyPressedEventHandler.go
- ICoreWebView2BytesReceivedChangedEventHandler.go
- ICoreWebView2Controller.go
- ICoreWebView2Controller2.go
- ICoreWebView2CreateCoreWebView2ControllerCompletedHandler.go
- ICoreWebView2DownloadOperation.go
- ICoreWebView2DownloadStartingEventArgs.go
- ICoreWebView2DownloadStartingEventHandler.go
- ICoreWebView2EstimatedEndTimeChangedEventHandler.go
- ICoreWebView2NavigationCompletedEventArgs.go
- ICoreWebView2NavigationCompletedEventHandler.go
- ICoreWebView2Settings.go
- ICoreWebView2StateChangedEventHandler.go
- ICoreWebView2WebResourceRequest.go
- ICoreWebView2WebResourceRequestedEventArgs.go
- ICoreWebView2WebResourceRequestedEventHandler.go
- ICoreWebView2WebResourceResponse.go
- ICoreWebView2_2.go
- ICoreWebView2_3.go
- ICoreWebView2_4.go
- ICoreWebViewSettings.go
- comproc.go
- comproc_go18.go
- guid.go